# Sungear

## Introduction

Sungear visulization.

## Install

```bash
# if you want the standalone web app
$ pip install sungear[web]

# if you only want to use the python fuctions
$ pip install sungear

```

## Example

```bash
$ python -m sungear
```

Then open browser to http://localhost:5000 to use.

## License

[MIT](./LICENSE)

## Reference

1. Christopher S. Poultney, Rodrigo A. Gutiérrez, Manpreet S. Katari, Miriam L. Gifford, W. Bradford Paley, Gloria M. Coruzzi, Dennis E. Shasha, Sungear: interactive visualization and functional analysis of genomic datasets, Bioinformatics, Volume 23, Issue 2, 15 January 2007, Pages 259–261, https://doi.org/10.1093/bioinformatics/btl496
